class RunnerFilter(object):
    framework = 'all'
    checks = []
    skip_checks = []
    external_check_ids = set()

    def __init__(self, framework='all', checks=None, skip_checks=None):
        if checks is None:
            checks = []
        if isinstance(checks, str):
            self.checks = checks.split(",")
        else:
            self.checks = checks

        if skip_checks is None:
            skip_checks = []
        if isinstance(skip_checks, str):
            self.skip_checks = skip_checks.split(",")
        else:
            self.skip_checks = skip_checks
        self.framework = framework

    def notify_external_check(self, check_id):
        self.external_check_ids.add(check_id)

    def should_run_check(self, check_id):
        if check_id in self.external_check_ids:
            pass        # enabled unless skipped
        elif self.checks:
            if check_id in self.checks:
                return True
            else:
                return False
        if self.skip_checks and check_id in self.skip_checks:
            return False
        return True



import logging
import shutil
from git import Repo

from checkov.common.goget.base_getter import BaseGetter


class GitGetter(BaseGetter):
    def __init__(self, url):
        self.logger = logging.getLogger(__name__)
        super().__init__(url)

    def do_get(self):
        clone_dir = self.temp_dir + "/clone/"
        result_dir = self.temp_dir + "/result/"


        if ".git//" in self.url:
            git_url, internal_dir = self.url.split(".git//")
            git_url = git_url + ".git"
            self.logger.debug("cloning {} to {}".format(git_url,clone_dir))
            Repo.clone_from(git_url, clone_dir)

            shutil.copytree(clone_dir + internal_dir, result_dir)
        else:
            self.logger.debug("cloning {} to {}".format(self.url,clone_dir))
            Repo.clone_from(self.url, clone_dir)
            shutil.copytree(clone_dir, result_dir)
        return result_dir




from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck


class ECSClusterContainerInsights(BaseResourceCheck):
    def __init__(self):
        name = "Ensure container insights are enabled on ECS cluster"
        id = "CKV_AWS_65"
        supported_resources = ['aws_ecs_cluster']
        categories = [CheckCategories.LOGGING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        if 'setting' in conf.keys():
            setting_conf = conf['setting']
            for setting in setting_conf:
                if isinstance(setting, dict) and setting['name'] == ['containerInsights'] and setting['value'] == ['enabled']:
                    return CheckResult.PASSED
        return CheckResult.FAILED


check = ECSClusterContainerInsights()



from checkov.common.checks.base_check_registry import BaseCheckRegistry


class Registry(BaseCheckRegistry):

    def __init__(self):
        super().__init__()

    def extract_entity_details(self, entity):
        function_type = f"serverless_{entity['provider_type']}"
        conf = entity["function"]
        return function_type, conf

    def scan(self, scanned_file, entity, skipped_checks, runner_filter):
        entity_type, entity_configuration = self.extract_entity_details(entity)
        results = {}
        checks = self.get_checks(entity_type)
        for check in checks:
            skip_info = {}
            if skipped_checks:
                if check.id in [x['id'] for x in skipped_checks]:
                    skip_info = [x for x in skipped_checks if x['id'] == check.id][0]

            if runner_filter.should_run_check(check.id):
                self.logger.debug("Running check: {} on file {}".format(check.name, scanned_file))
                result = check.run(scanned_file=scanned_file, entity_configuration=entity_configuration,
                                   entity_name=entity_type, entity_type=entity_type, skip_info=skip_info)
                results[check] = result
        return results



from abc import abstractmethod

import dpath
from checkov.common.models.enums import CheckResult
from checkov.kubernetes.base_spec_check import BaseK8Check


class BaseSpecOmittedOrValueCheck(BaseK8Check):
    def __init__(self, name, id, categories, supported_entities):
        super().__init__(name=name, id=id, categories=categories, supported_entities=supported_entities)

    def scan_spec_conf(self, conf):
        inspected_key = self.get_inspected_key()
        if dpath.util.search(conf, inspected_key,yielded=False) != {}:
            if dpath.util.get(conf, inspected_key) != self.get_expected_value():
                return CheckResult.FAILED
        return CheckResult.PASSED

    @abstractmethod
    def get_inspected_key(self):
        raise NotImplemented()

    def get_expected_value(self):
        # default expected value. can be override by derived class
        return False
